//+------------------------------------------------------------------+
//|                                                           MA.mq5 |
//|                                                            H.A.M |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "H.A.M"
#property link      "https://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\MySignals\Merge.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingNone.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title              ="MA";         // Document name
ulong                    Expert_MagicNumber        =14178;        // 
bool                     Expert_EveryTick          =false;        // 
//--- inputs for main signal
input int                Signal_ThresholdOpen      =10;           // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose     =10;           // Signal threshold value to close [0...100]
input double             Signal_PriceLevel         =0.0;          // Price level to execute a deal
input double             Signal_StopLevel          =50.0;         // Stop Loss level (in points)
input double             Signal_TakeLevel          =50.0;         // Take Profit level (in points)
input int                Signal_Expiration         =4;            // Expiration of pending orders (in bars)
input int                Signal_Merged_FastPeriod  =8;            // Merged(8,MODE_EMA,20,...) Period of fast MA
input ENUM_MA_METHOD     Signal_Merged_FastMethod  =MODE_EMA;     // Merged(8,MODE_EMA,20,...) Method of fast MA
input int                Signal_Merged_SlowPeriod  =20;           // Merged(8,MODE_EMA,20,...) Period of slow MA
input ENUM_MA_METHOD     Signal_Merged_SlowMethod  =MODE_EMA;     // Merged(8,MODE_EMA,20,...) Method of slow MA
input int                Signal_Merged_SMA5Period  =5;            // Merged(8,MODE_EMA,20,...) Period of fast MA
input ENUM_APPLIED_PRICE Signal_Merged_SMA5Applied =PRICE_MEDIAN; // Merged(8,MODE_EMA,20,...) Prices to apply to
input int                Signal_Merged_SMA34Period =34;           // Merged(8,MODE_EMA,20,...) Period of sma34 MA
input ENUM_MA_METHOD     Signal_Merged_SMA34Method =MODE_SMA;     // Merged(8,MODE_EMA,20,...) Method of sma34 MA
input ENUM_APPLIED_PRICE Signal_Merged_SMA34Applied=PRICE_MEDIAN; // Merged(8,MODE_EMA,20,...) Prices to apply to
input double             Signal_Merged_Weight      =1.0;          // Merged(8,MODE_EMA,20,...) Weight [0...1.0]
//--- inputs for money
input double             Money_FixLot_Percent      =10.0;         // Percent
input double             Money_FixLot_Lots         =0.01;         // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter Merged_s
   Merged_s *filter0=new Merged_s;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.FastPeriod(Signal_Merged_FastPeriod);
   filter0.FastMethod(Signal_Merged_FastMethod);
   filter0.SlowPeriod(Signal_Merged_SlowPeriod);
   filter0.SlowMethod(Signal_Merged_SlowMethod);
   filter0.SMA5Period(Signal_Merged_SMA5Period);
   filter0.SMA5Applied(Signal_Merged_SMA5Applied);
   filter0.SMA34Period(Signal_Merged_SMA34Period);
   filter0.SMA34Method(Signal_Merged_SMA34Method);
   filter0.SMA34Applied(Signal_Merged_SMA34Applied);
   filter0.Weight(Signal_Merged_Weight);
//--- Creation of trailing object
   CTrailingNone *trailing=new CTrailingNone;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set trailing parameters
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set money parameters
   money.Percent(Money_FixLot_Percent);
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- ok
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   ExtExpert.OnTick();
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
